====================
crypto-price-rss
====================

.. image:: https://img.shields.io/pypi/v/crypto-price-rss.svg
        :target: https://pypi.python.org/pypi/crypto-price-rss

.. image:: https://img.shields.io/travis/narfman0/crypto-price-rss.svg
        :target: https://travis-ci.org/narfman0/crypto-price-rss

Dump crypto prices to rss

Usage
=====

Optional: set up virtualenv environment with::

    virtualenv venv
    source venv/bin/activate

Install requirements::

    pip install -r requirements.txt

CLI
---

The command line interface may be used to dump your timeline to stdout::

    crypto_price_rss

License
=======

Copyright (c) 2017 Jon Robison

See included LICENSE for licensing information
